@@ -2,7 +2,7 @@
    tio.c - timed io functions
    This file is part of the nss-pam-ldapd library.
 
-   Copyright (C) 2007, 2008 Arthur de Jong
+   Copyright (C) 2007, 2008, 2010 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -78,7 +78,7 @@ static inline void tio_tv_add(struct timeval *tv1, const struct timeval *tv2)
 {
   /* BUG: we hope that this does not overflow */
   tv1->tv_usec+=tv2->tv_usec;
-  if (tv1->tv_usec>1000000)
+  if (tv1->tv_usec>=1000000)
   {
     tv1->tv_usec-=1000000;
     tv1->tv_sec+=1;
@@ -117,7 +117,7 @@ static inline int tio_tv_remaining(struct timeval *tv, const struct timeval *dea
     return -1;
   /* update tv */
   tv->tv_sec=deadline->tv_sec-tv->tv_sec;
-  if (tv->tv_usec<deadline->tv_usec)
+  if (tv->tv_usec<=deadline->tv_usec)
     tv->tv_usec=deadline->tv_usec-tv->tv_usec;
   else
   {
@@ -295,7 +295,12 @@ int tio_read(TFILE *fp, void *buf, size_t count)
     /* read the input in the buffer */
     rv=read(fp->fd,fp->readbuffer.buffer+fp->readbuffer.start,fp->readbuffer.size-fp->readbuffer.start);
     /* check for errors */
-    if ((rv==0)||((rv<0)&&(errno!=EINTR)&&(errno!=EAGAIN)))
+    if (rv==0)
+    {
+      errno=ECONNRESET;
+      return -1;
+    }
+    else if ((rv<0)&&(errno!=EINTR)&&(errno!=EAGAIN))
       return -1; /* something went wrong with the read */
     /* skip the read part in the buffer */
     fp->readbuffer.len=rv;
