@@ -5,7 +5,7 @@
 
    Copyright (C) 1997-2005 Luke Howard
    Copyright (C) 2007 West Consulting
-   Copyright (C) 2007, 2008, 2009, 2010 Arthur de Jong
+   Copyright (C) 2007, 2008, 2009, 2010, 2011 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -23,13 +23,14 @@
    02110-1301 USA
 */
 
-#ifndef _CFG_H
-#define _CFG_H
+#ifndef NSLCD__CFG_H
+#define NSLCD__CFG_H
 
 #include <unistd.h>
 #include <sys/types.h>
 #include <lber.h>
 #include <ldap.h>
+#include <regex.h>
 
 #include "compat/attrs.h"
 #include "common/set.h"
@@ -95,18 +96,18 @@ struct ldap_config
   char *ldc_bindpw;
   /* bind DN for password modification by administrator */
   char *ldc_rootpwmoddn;
+  /* bind password for password modification by root */
+  char *ldc_rootpwmodpw;
+  /* sasl mech */
+  char *ldc_sasl_mech;
+  /* sasl realm */
+  char *ldc_sasl_realm;
   /* sasl authentication id */
   char *ldc_sasl_authcid;
   /* sasl authorization id */
   char *ldc_sasl_authzid;
   /* sasl security */
   char *ldc_sasl_secprops;
-  /* sasl mech */
-  char *ldc_sasl_mech;
-  /* sasl realm */
-  char *ldc_sasl_realm;
-  /* do we use sasl when binding? */
-  int ldc_usesasl;
   /* base DN, eg. dc=gnu,dc=org */
   const char *ldc_bases[NSS_LDAP_CONFIG_MAX_BASES];
   /* scope for searches */
@@ -133,11 +134,14 @@ struct ldap_config
   int ldc_restart;
   /* set to a greater than 0 to enable handling of paged results with the specified size */
   int ldc_pagesize;
-  /* the users for which no initgroups() searches should be done
-     Note: because we use a set here comparisons will be case-insensitive */
+  /* the users for which no initgroups() searches should be done */
   SET *ldc_nss_initgroups_ignoreusers;
   /* the search that should be performed to do autorisation checks */
   char *ldc_pam_authz_search;
+  /* minimum uid for users retreived from LDAP */
+  uid_t ldc_nss_min_uid;
+  /* the regular expression to determine valid names */
+  regex_t validnames;
 };
 
 /* this is a pointer to the global configuration, it should be available
@@ -149,4 +153,4 @@ extern struct ldap_config *nslcd_cfg;
    if an error occurs. */
 void cfg_init(const char *fname);
 
-#endif /* _CFG_H */
+#endif /* NSLCD__CFG_H */
