@@ -5,7 +5,7 @@
 
    Copyright (C) 1997-2005 Luke Howard
    Copyright (C) 2006 West Consulting
-   Copyright (C) 2006, 2007, 2009, 2010 Arthur de Jong
+   Copyright (C) 2006, 2007, 2009, 2010, 2011 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -56,7 +56,6 @@ const char *network_filter = "(objectClass=ipNetwork)";
 /* the attributes used in searches */
 const char *attmap_network_cn              = "cn";
 const char *attmap_network_ipNetworkNumber = "ipNetworkNumber";
-/*const char *attmap_network_ipNetmaskNumber = "ipNetmaskNumber"; */
 
 /* the attribute list to request with searches */
 static const char *network_attrs[3];
@@ -77,18 +76,18 @@ static int mkfilter_network_byname(const char *name,
                     attmap_network_cn,safename);
 }
 
-static int mkfilter_network_byaddr(const char *name,
+static int mkfilter_network_byaddr(const char *addrname,
                                    char *buffer,size_t buflen)
 {
-  char safename[64];
+  char safeaddr[64];
   /* escape attribute */
-  if (myldap_escape(name,safename,sizeof(safename)))
+  if (myldap_escape(addrname,safeaddr,sizeof(safeaddr)))
     return -1;
   /* build filter */
   return mysnprintf(buffer,buflen,
                     "(&%s(%s=%s))",
                     network_filter,
-                    attmap_network_ipNetworkNumber,safename);
+                    attmap_network_ipNetworkNumber,safeaddr);
 }
 
 void network_init(void)
@@ -154,8 +153,8 @@ NSLCD_HANDLE(
   network,byname,
   char name[256];
   char filter[1024];
-  READ_STRING(fp,name);,
-  log_log(LOG_DEBUG,"nslcd_network_byname(%s)",name);,
+  READ_STRING(fp,name);
+  log_setrequest("network=\"%s\"",name);,
   NSLCD_ACTION_NETWORK_BYNAME,
   mkfilter_network_byname(name,filter,sizeof(filter)),
   write_network(fp,entry)
@@ -166,26 +165,25 @@ NSLCD_HANDLE(
   int af;
   char addr[64];
   int len=sizeof(addr);
-  char name[64];
+  char addrname[64];
   char filter[1024];
   READ_ADDRESS(fp,addr,len,af);
   /* translate the address to a string */
-  if (inet_ntop(af,addr,name,sizeof(name))==NULL)
+  if (inet_ntop(af,addr,addrname,sizeof(addrname))==NULL)
   {
     log_log(LOG_WARNING,"unable to convert address to string");
     return -1;
-  },
-  log_log(LOG_DEBUG,"nslcd_network_byaddr(%s)",name);,
+  }
+  log_setrequest("network=%s",addrname);,
   NSLCD_ACTION_NETWORK_BYADDR,
-  mkfilter_network_byaddr(name,filter,sizeof(filter)),
+  mkfilter_network_byaddr(addrname,filter,sizeof(filter)),
   write_network(fp,entry)
 )
 
 NSLCD_HANDLE(
   network,all,
   const char *filter;
-  /* no parameters to read */,
-  log_log(LOG_DEBUG,"nslcd_network_all()");,
+  log_setrequest("network(all)");,
   NSLCD_ACTION_NETWORK_ALL,
   (filter=network_filter,0),
   write_network(fp,entry)
